@@ -5,7 +5,6 @@ import sentry_sdk
 from sentry_sdk.integrations.django import DjangoIntegration
 from garpix_notify.settings import *  # noqa
 
-
 env = Env()
 env.read_env(os.path.join(BASE_DIR, '.env'), recurse=True)
 
@@ -51,6 +50,7 @@ INSTALLED_APPS = [
     # garpixcms
     'garpix_utils',
     'eqator',
+    'garpix_admin_lock',
     'garpix_page',
     'garpix_menu',
     'garpix_notify',
@@ -98,7 +98,6 @@ TEMPLATES = [
 
 WSGI_APPLICATION = 'app.wsgi.application'
 
-
 # Database
 # https://docs.djangoproject.com/en/3.1/ref/settings/#databases
 
@@ -113,7 +112,6 @@ DATABASES = {
     },
 }
 
-
 # Password validation
 # https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators
 
@@ -132,7 +130,6 @@ AUTH_PASSWORD_VALIDATORS = [
     },
 ]
 
-
 # Internationalization
 # https://docs.djangoproject.com/en/3.1/topics/i18n/
 
@@ -151,7 +148,6 @@ USE_L10N = True
 
 USE_TZ = True
 
-
 # Static files (CSS, JavaScript, Images)
 # https://docs.djangoproject.com/en/3.1/howto/static-files/
 
@@ -209,6 +205,7 @@ MIGRATION_MODULES = {
     'garpix_menu': 'app.migrations.garpix_menu',
     'garpix_notify': 'app.migrations.garpix_notify',
     'garpixcms': 'app.migrations.garpixcms',
+    'garpix_admin_lock': 'app.migrations.garpix_admin_lock'
 }
 
 DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
@@ -300,7 +297,6 @@ if ENABLE_GARPIX_AUTH:
         'garpix_auth',
     ]
 
-
 GARPIX_PAGE_ADMIN_LIST_PER_PAGE = 25
 GARPIX_PAGE_GLOBAL_CONTEXT = 'garpixcms.contexts.global_context.global_context'
 
